@@ -41,7 +41,7 @@
 #include "macro.h"
 #include "core-util.h"
 
-extern char *pactl (char *, char *, char *);
+extern char *pactl (char *, int, char *);
 extern char sink_info[10][100];
 
 static pa_context *context = NULL;
@@ -188,7 +188,7 @@ userdata = userdata; // avoid notification
     }
     sprintf (sink_info[i->index] + 52, " Muted: %3s Volume:%s",
                pa_yes_no_localised(i->mute), str + x);
-}
+} // get_sink_info_callback
 
 static void simple_callback (pa_context *c, int success, void *userdata)
 {
@@ -245,7 +245,7 @@ static void get_sink_volume_callback (pa_context *c, const pa_sink_info *i, int
 userdata = userdata; // avoid notification
     pa_cvolume cv;
 
-    if (is_last < 0) {
+    if (is_last < 0) {                                                 
         quit(1);
         return;
     }
@@ -259,11 +259,11 @@ userdata = userdata; // avoid notification
     fill_volume(&cv, i->channel_map.channels);
 
     pa_operation_unref(pa_context_set_sink_volume_by_name(c, sink_name, &cv, simple_callback, NULL));
-}
+} // get_sink_volume_callback
 
 static void sink_toggle_mute_callback (pa_context *c, const pa_sink_info *i, int is_last, void *userdata)
 {
-userdata = userdata; // avoid notification
+userdata = userdata; // avoid notification                              
     if (is_last < 0) {
         quit(1);
         return;
@@ -275,7 +275,7 @@ userdata = userdata; // avoid notification
     pa_assert(i);
 
     pa_operation_unref(pa_context_set_sink_mute_by_name(c, i->name, !i->mute, simple_callback, NULL));
-}
+} // sink_toggle_mute_callback
 
 #define MAX_FORMATS 256
 
@@ -454,14 +454,16 @@ userdata = userdata; // avoid notification
         default:
             quit(1);
     }
-}
+} // context_state_callback
 
-char *pactl (char *cmd, char *device, char *arg)
+char *pactl (char *cmd, int dev, char *arg)
 {
+    char device[5];
     pa_mainloop *m = NULL;
     int ret = 1;
     char *server = NULL;
 
+    sprintf (device, "%d", dev);
     setlocale(LC_ALL, "");
 \
     proplist = pa_proplist_new();
@@ -544,4 +546,4 @@ quit:
         pa_proplist_free(proplist);
 
     return (char *) sink_info;
-}
+} // pactl
